package com.gic.operation.web.controller;

import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.dto.rule.RuleClassifyDTO;
import com.gic.enterprise.dto.rule.RuleClassifySceneDTO;
import com.gic.enterprise.dto.rule.RuleDTO;
import com.gic.enterprise.service.ConfigRuleApiService;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.operation.web.vo.SceneCategoryVO;
import com.gic.operation.web.vo.configrule.RuleClassifySceneVO;
import com.gic.operation.web.vo.configrule.RuleClassifyVO;
import com.gic.operation.web.vo.configrule.RuleVO;
import com.gic.rule.manage.api.service.DealOperationApiService;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/config/rule")
public class ConfigRuleController {

    private static final Logger LOGGER = LogManager.getLogger(ConfigRuleController.class);

    @Autowired
    private ConfigRuleApiService configRuleApiService;
    @Autowired
    private DealOperationApiService dealOperationApiService;

    @RequestMapping("/saveRule")
    public RestResponse saveRule(RuleDTO dto) {
        return ResultControllerUtils.commonResult(configRuleApiService.saveRule(dto));
    }

    @RequestMapping("/editRule")
    public RestResponse editRule(RuleDTO dto) {
        return ResultControllerUtils.commonResult(configRuleApiService.editRule(dto));
    }

    @RequestMapping("/listRule")
    public RestResponse listRule(String search) {
        return ResultControllerUtils.commonResult(configRuleApiService.listRule(search), RuleVO.class);
    }

    @RequestMapping("/getRule")
    public RestResponse getRule(Integer ruleId) {
        return ResultControllerUtils.commonResultOne(configRuleApiService.getDetailByRuleId(ruleId), RuleVO.class);
    }

    @RequestMapping("/copyRule")
    public RestResponse copyRule(Integer ruleId) {
        return ResultControllerUtils.commonResult(configRuleApiService.copyRule(ruleId));
    }

    @RequestMapping("/saveRuleClassify")
    public RestResponse saveRuleClassify(RuleClassifyDTO dto) {
        return ResultControllerUtils.commonResult(configRuleApiService.saveRuleClassify(dto));
    }

    @RequestMapping("/editRuleClassify")
    public RestResponse editRuleClassify(RuleClassifyDTO dto) {
        return ResultControllerUtils.commonResult(configRuleApiService.editRuleClassify(dto));
    }

    @RequestMapping("/listRuleClassify")
    public RestResponse listRuleClassify(String search, Integer ruleId, Integer pageNum, Integer pageSize) {
        return ResultControllerUtils.commonPageResult(
                configRuleApiService.listRuleClassify(search, ruleId, pageNum, pageSize), RuleClassifyVO.class);
    }

    @RequestMapping("/getRuleClassify")
    public RestResponse getRuleClassify(Integer ruleId) {
        return ResultControllerUtils.commonResultOne(configRuleApiService.getDetailByRuleId(ruleId), RuleClassifyVO.class);
    }

    @RequestMapping("/saveRuleClassifyScene")
    public RestResponse saveRuleClassifyScene(RuleClassifySceneDTO dto) {
        return ResultControllerUtils.commonResult(configRuleApiService.saveRuleClassifyScene(dto));
    }

    @RequestMapping("/editRuleClassifyScene")
    public RestResponse editRuleClassifyScene(RuleClassifySceneDTO dto) {
        return ResultControllerUtils.commonResult(configRuleApiService.editRuleClassifyScene(dto));
    }

    @RequestMapping("/listRuleClassifyScene")
    public RestResponse listRuleClassifyScene(String search, Integer ruleId, Integer pageNum, Integer pageSize) {
        return ResultControllerUtils.commonPageResult(
                configRuleApiService.listRuleClassifyScene(search, ruleId, pageNum, pageSize),
                RuleClassifySceneVO.class);
    }

    @RequestMapping("/getRuleClassifyScene")
    public RestResponse getRuleClassifyScene(Integer ruleId) {
        return ResultControllerUtils.commonResultOne(configRuleApiService.getDetailByRuleId(ruleId), RuleClassifySceneVO.class);
    }

    @RequestMapping("/deleteClassify")
    public RestResponse deleteClassify(Integer ruleId) {
        return ResultControllerUtils.commonResult(configRuleApiService.deleteRuleClassify(ruleId));
    }

    @RequestMapping("/deleteClassifyScene")
    public RestResponse deleteClassifyScene(Integer ruleId) {
        return ResultControllerUtils.commonResult(configRuleApiService.deleteRuleClassifyScene(ruleId));
    }

    @RequestMapping("/list-scene")
    public RestResponse listScene(String search, Integer pageNum, Integer pageSize) {
        return ResultControllerUtils.commonPageResult(
                dealOperationApiService.pageSceneCategory(search, pageNum, pageSize), SceneCategoryVO.class);
    }

    @RequestMapping("/list-market-object")
    public RestResponse listMarketObject() {
        List<Map<String, String>> result = new ArrayList<>(3);
        Map<String, String> map = new HashMap<>(8);
        map.put("1", "会员卡域");
        map.put("2", "服务号域");
        map.put("3", "小程序域");
        result.add(map);
        return RestResponse.success(result);
    }
}
